"""
Custom middleware
"""
import time
import logging

from django.conf import settings

logger = logging.getLogger(__name__)


class LongRequestMiddleware(object):

    """Long request middleware, remember to put it first
    """

    def __init__(self):
        """Initialize timeout with PATCHY_LONG_REQUEST_TIMEOUT with default to one second
        """
        try:
            self.timeout = settings.PATCHY_LONG_REQUEST_TIMEOUT
        except AttributeError:
            self.timeout = 1

    def process_request(self, request):
        """record the time in
        """
        self._start = time.time()

    def process_response(self, request, response):
        """record the time out
        """
        self._end = time.time()
        elapsed = self._end - self._start
        if elapsed > self.timeout:
            # too long and log to target
            logger.error('[Long Request]Path: %s, Time: %s s' % (request.path, elapsed))
        response['X-ELAPSED'] = elapsed
        return response



import time
import logging

from django.conf import settings
from django.db.backends.utils import CursorWrapper

logger = logging.getLogger(__name__)

try:
    TIMEOUT = settings.PATCHY_LONG_SQL_TIMEOUT
except AttributeError:
    TIMEOUT = 0.05  # 50 ms


original = CursorWrapper.execute


def long_sql_execute_wrapper(*args, **kwargs):
    try:
        start = time.time()
        result = original(*args, **kwargs)
        end = time.time()
        return result
    finally:
        duration = end - start
        if duration > TIMEOUT:
            try:
                message = 'SQL: (%s), Args: (%s), Execution time: %.6fs' % (args[1], args[2], duration)
            except IndexError:
                message = 'SQL: (%s), Args: (), Execution time: %.6fs' % (args[1], duration)
            logger.error(message)
